metapho

Package metapho |
[hide private]

# Source Code for Package metapho

     1  #!/usr/bin/env python
     2
     3  # metapho: an image tagger and viewer.
     4
     5  # Copyright 2013,2016 by Akkana Peck: share and enjoy under the GPL v2 or later.
     6
     7  '''MetaPho: an image tagger and viewer.'''
     8
     9  __version__ = "0.5"
    10  __author__ = "Akkana Peck <akkana@shallowsky.com>"
    11  __license__ = "GPL v2"
    12  __all__ = [ 'Image', 'Tagger', 'Organizer' ]
    13
    14  from .metapho import *
    15